==> synthdef-json-decoder-0.5.0.tgz: package/lib/SynthDefDecoder2.js <==
"use strict";

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var nmap = require("nmap");
var fromPairs = require("lodash.frompairs");

var SynthDefDecoder2 = function () {
  function SynthDefDecoder2(reader) {
    _classCallCheck(this, SynthDefDecoder2);

    this.reader = reader;
  }

  _createClass(SynthDefDecoder2, [{
    key: "decode",
    value: function decode() {
      var _this = this;

      var name = this.readNameOfSynthDef();
      var numberOfConstants = this.readNumberOfConstants();
      var consts = nmap(numberOfConstants, function () {
        return toJSONableNumber(_this.readConstantValue());
      });
      var numberOfParamValues = this.readNumberOfParamValues();
      var paramValues = nmap(numberOfParamValues, function () {
        return toJSONableNumber(_this.readInitialParamValue());
      });
      var numberOfParamIndices = this.readNumberOfParamIndices();
      var paramIndices = toParamIndices(nmap(numberOfParamIndices, function () {
        return _this.readParamItems();
      }), numberOfParamValues);
      var numberOfUnits = this.readNumberOfUnits();
      var units = nmap(numberOfUnits, function () {
        return _this.readUGenSpec();
      });
      var numberOfVariants = this.readNumberOfVariants();
      var variants = fromPairs(nmap(numberOfVariants, function () {
        return _this.readVariantSpec(numberOfParamValues);
      }));

      return { name: name, consts: consts, paramValues: paramValues, paramIndices: paramIndices, units: units, variants: variants };
    }
  }, {
    key: "readParamItems",
    value: function readParamItems() {
      return [this.readParamName(), this.readParamNameIndex()];
    }
  }, {
    key: "readUGenSpec",
    value: function readUGenSpec() {
      var _this2 = this;

      var name = this.readUGenName();
      var rate = this.readUGenRate();
      var numberOfInputs = this.readUGenNumberOfInputs();
      var numberOfOutputs = this.readUGenNumberOfOutputs();
      var specialIndex = this.readUGenSpecialIndex();
      var inputSpecs = nmap(numberOfInputs, function () {
        return _this2.readUGenInputSpec();
      });
      var outputSpecs = nmap(numberOfOutputs, function () {
        return _this2.readUGenOutputSpec();
      });

      return [name, rate, specialIndex, inputSpecs, outputSpecs];
    }
  }, {
    key: "readUGenInputSpec",
    value: function readUGenInputSpec() {
      var indexOfUGen = this.readIndexOfUGen();
      var indexOfUGenOutput = this.readIndexOfUGenOutput();

      return [indexOfUGen, indexOfUGenOutput];
    }
  }, {
    key: "readUGenOutputSpec",
    value: function readUGenOutputSpec() {
      var calculationRate = this.readUGenRate();

      return calculationRate;
    }
  }, {
    key: "readVariantSpec",
    value: function readVariantSpec(numberOfParamValues) {
      var _this3 = this;

      var name = this.readVariantName().replace(/^.+?\./, "");
      var values = nmap(numberOfParamValues, function () {
        return toJSONableNumber(_this3.readVariantValue());
      });

      return [name, values];
    }
  }, {
    key: "readNameOfSynthDef",
    value: function readNameOfSynthDef() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readNumberOfConstants",
    value: function readNumberOfConstants() {
      return this.reader.readInt32();
    }
  }, {
    key: "readConstantValue",
    value: function readConstantValue() {
      return this.reader.readFloat32();
    }
  }, {
    key: "readNumberOfParamValues",
    value: function readNumberOfParamValues() {
      return this.reader.readInt32();
    }
  }, {
    key: "readInitialParamValue",
    value: function readInitialParamValue() {
      return this.reader.readFloat32();
    }
  }, {
    key: "readNumberOfParamIndices",
    value: function readNumberOfParamIndices() {
      return this.reader.readInt32();
    }
  }, {
    key: "readParamName",
    value: function readParamName() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readParamNameIndex",
    value: function readParamNameIndex() {
      return this.reader.readInt32();
    }
  }, {
    key: "readNumberOfUnits",
    value: function readNumberOfUnits() {
      return this.reader.readInt32();
    }
  }, {
    key: "readUGenName",
    value: function readUGenName() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readUGenRate",
    value: function readUGenRate() {
      return this.reader.readInt8();
    }
  }, {
    key: "readUGenNumberOfInputs",
    value: function readUGenNumberOfInputs() {
      return this.reader.readInt32();
    }
  }, {
    key: "readUGenNumberOfOutputs",
    value: function readUGenNumberOfOutputs() {
      return this.reader.readInt32();
    }
  }, {
    key: "readUGenSpecialIndex",
    value: function readUGenSpecialIndex() {
      return this.reader.readInt16();
    }
  }, {
    key: "readIndexOfUGen",
    value: function readIndexOfUGen() {
      return this.reader.readInt32();
    }
  }, {
    key: "readIndexOfUGenOutput",
    value: function readIndexOfUGenOutput() {
      return this.reader.readInt32();
    }
  }, {
    key: "readNumberOfVariants",
    value: function readNumberOfVariants() {
      return this.reader.readInt16();
    }
  }, {
    key: "readVariantName",
    value: function readVariantName() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readVariantValue",
    value: function readVariantValue() {
      return this.reader.readFloat32();
    }
  }]);

  return SynthDefDecoder2;
}();

function toJSONableNumber(value) {
  return value === Infinity || value === -Infinity ? "" + value : value;
}

function toParamIndices(listOfParamIndices, numberOfParamValues) {
  var paramIndices = {};

  listOfParamIndices.sort(function (a, b) {
    return b[1] - a[1];
  }).reduce(function (lastIndex, _ref) {
    var _ref2 = _slicedToArray(_ref, 2);

    var name = _ref2[0];
    var index = _ref2[1];

    paramIndices[name] = { index: index, length: lastIndex - index };
    return index;
  }, numberOfParamValues);

  return paramIndices;
}

module.exports = SynthDefDecoder2;

==> synthdef-json-decoder-1.0.1.tgz: package/lib/SynthDefDecoder2.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var nmap = require("nmap");

var SynthDefDecoder2 = function () {
  function SynthDefDecoder2(reader) {
    _classCallCheck(this, SynthDefDecoder2);

    this.reader = reader;
  }

  _createClass(SynthDefDecoder2, [{
    key: "decode",
    value: function decode() {
      var _this = this;

      var name = this.readNameOfSynthDef();
      var numberOfConstants = this.readNumberOfConstants();
      var consts = nmap(numberOfConstants, function () {
        return toJSONableNumber(_this.readConstantValue());
      });
      var numberOfParamValues = this.readNumberOfParamValues();
      var paramValues = nmap(numberOfParamValues, function () {
        return toJSONableNumber(_this.readInitialParamValue());
      });
      var numberOfParamIndices = this.readNumberOfParamIndices();
      var paramIndices = toParamIndices(nmap(numberOfParamIndices, function () {
        return _this.readParamItems();
      }), numberOfParamValues);
      var numberOfUnits = this.readNumberOfUnits();
      var units = nmap(numberOfUnits, function () {
        return _this.readUGenSpec();
      });
      var numberOfVariants = this.readNumberOfVariants();
      var variants = nmap(numberOfVariants, function () {
        return _this.readVariantSpec(numberOfParamValues);
      });

      return { name: name, consts: consts, paramValues: paramValues, paramIndices: paramIndices, units: units, variants: variants };
    }
  }, {
    key: "readParamItems",
    value: function readParamItems() {
      return { name: this.readParamName(), index: this.readParamNameIndex() };
    }
  }, {
    key: "readUGenSpec",
    value: function readUGenSpec() {
      var _this2 = this;

      var name = this.readUGenName();
      var rate = this.readUGenRate();
      var numberOfInputs = this.readUGenNumberOfInputs();
      var numberOfOutputs = this.readUGenNumberOfOutputs();
      var specialIndex = this.readUGenSpecialIndex();
      var inputSpecs = nmap(numberOfInputs, function () {
        return _this2.readUGenInputSpec();
      });
      var outputSpecs = nmap(numberOfOutputs, function () {
        return _this2.readUGenOutputSpec();
      });

      return [name, rate, specialIndex, inputSpecs, outputSpecs];
    }
  }, {
    key: "readUGenInputSpec",
    value: function readUGenInputSpec() {
      var indexOfUGen = this.readIndexOfUGen();
      var indexOfUGenOutput = this.readIndexOfUGenOutput();

      return [indexOfUGen, indexOfUGenOutput];
    }
  }, {
    key: "readUGenOutputSpec",
    value: function readUGenOutputSpec() {
      var calculationRate = this.readUGenRate();

      return calculationRate;
    }
  }, {
    key: "readVariantSpec",
    value: function readVariantSpec(numberOfParamValues) {
      var _this3 = this;

      var name = this.readVariantName().replace(/^.+?\./, "");
      var values = nmap(numberOfParamValues, function () {
        return toJSONableNumber(_this3.readVariantValue());
      });

      return { name: name, values: values };
    }
  }, {
    key: "readNameOfSynthDef",
    value: function readNameOfSynthDef() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readNumberOfConstants",
    value: function readNumberOfConstants() {
      return this.reader.readInt32();
    }
  }, {
    key: "readConstantValue",
    value: function readConstantValue() {
      return this.reader.readFloat32();
    }
  }, {
    key: "readNumberOfParamValues",
    value: function readNumberOfParamValues() {
      return this.reader.readInt32();
    }
  }, {
    key: "readInitialParamValue",
    value: function readInitialParamValue() {
      return this.reader.readFloat32();
    }
  }, {
    key: "readNumberOfParamIndices",
    value: function readNumberOfParamIndices() {
      return this.reader.readInt32();
    }
  }, {
    key: "readParamName",
    value: function readParamName() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readParamNameIndex",
    value: function readParamNameIndex() {
      return this.reader.readInt32();
    }
  }, {
    key: "readNumberOfUnits",
    value: function readNumberOfUnits() {
      return this.reader.readInt32();
    }
  }, {
    key: "readUGenName",
    value: function readUGenName() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readUGenRate",
    value: function readUGenRate() {
      return this.reader.readInt8();
    }
  }, {
    key: "readUGenNumberOfInputs",
    value: function readUGenNumberOfInputs() {
      return this.reader.readInt32();
    }
  }, {
    key: "readUGenNumberOfOutputs",
    value: function readUGenNumberOfOutputs() {
      return this.reader.readInt32();
    }
  }, {
    key: "readUGenSpecialIndex",
    value: function readUGenSpecialIndex() {
      return this.reader.readInt16();
    }
  }, {
    key: "readIndexOfUGen",
    value: function readIndexOfUGen() {
      return this.reader.readInt32();
    }
  }, {
    key: "readIndexOfUGenOutput",
    value: function readIndexOfUGenOutput() {
      return this.reader.readInt32();
    }
  }, {
    key: "readNumberOfVariants",
    value: function readNumberOfVariants() {
      return this.reader.readInt16();
    }
  }, {
    key: "readVariantName",
    value: function readVariantName() {
      return this.reader.readPascalString();
    }
  }, {
    key: "readVariantValue",
    value: function readVariantValue() {
      return this.reader.readFloat32();
    }
  }]);

  return SynthDefDecoder2;
}();

function toJSONableNumber(value) {
  return value === Infinity || value === -Infinity ? "" + value : value;
}

function toParamIndices(listOfParamIndices, numberOfParamValues) {
  listOfParamIndices.forEach(function (item, i) {
    var nextItem = listOfParamIndices[i + 1];
    var nextIndex = nextItem ? nextItem.index : numberOfParamValues;

    item.length = nextIndex - item.index;
  });
  return listOfParamIndices;
}

module.exports = SynthDefDecoder2;
